@@ -589,13 +589,23 @@ static int32_t wp_serial_config(void *pfe)
 
 	card->hw_iface.bus_write_4(card->hw,AFT_PORT_REG(card,AFT_SERIAL_LINE_CFG_REG),reg);
 
-	DEBUG_EVENT("%s: A140: Configurfed for 0x%08X CTS/DCD ISR=%s\n",
+	DEBUG_EVENT("%s: A140: Configurfed for 0x%08X CTS/DCD ISR=%s DTR=%i RTS=%i\n",
 			card->devname,
-			reg,card->wandev.ignore_front_end_status == WANOPT_YES?"Off":"On");
+			reg,card->wandev.ignore_front_end_status == WANOPT_YES?"Off":"On",
+			card->u.aft.cfg.serial_rts_ctrl == WANOPT_HIGH, card->u.aft.cfg.serial_dtr_ctrl == WANOPT_HIGH);
 
 	/* Raise RTS and DTR */
-	wan_set_bit(AFT_SERIAL_LCFG_RTS_BIT,&reg);
-	wan_set_bit(AFT_SERIAL_LCFG_DTR_BIT,&reg);
+	if (card->u.aft.cfg.serial_rts_ctrl == WANOPT_HIGH) {
+		wan_set_bit(AFT_SERIAL_LCFG_RTS_BIT,&reg);
+	} else {
+		wan_clear_bit(AFT_SERIAL_LCFG_RTS_BIT,&reg);
+	}
+
+	if (card->u.aft.cfg.serial_dtr_ctrl == WANOPT_HIGH) {
+		wan_set_bit(AFT_SERIAL_LCFG_DTR_BIT,&reg);
+	} else {
+		wan_clear_bit(AFT_SERIAL_LCFG_DTR_BIT,&reg);
+	}
 
 	card->hw_iface.bus_write_4(card->hw,AFT_PORT_REG(card,AFT_SERIAL_LINE_CFG_REG),reg);
 
